@@ -2,8 +2,9 @@ package GD::SecurityImage;
 use strict;
 use vars qw[@ISA $AUTOLOAD $VERSION $BACKEND];
 use GD::SecurityImage::Styles;
+use Carp qw(croak);
 
-$VERSION = '1.61';
+$VERSION = '1.62';
 
 sub import {
    my $class   = shift;
@@ -12,26 +13,30 @@ sub import {
    $BACKEND    = ''; # name of the back-end
    @ISA        = ();
    # load the drawing interface
-   if (exists $opt{use_magick} && $opt{use_magick}) {
+   if ( exists $opt{use_magick} && $opt{use_magick} ) {
       require GD::SecurityImage::Magick;
       $BACKEND = 'Magick';
-   } elsif (exists $opt{backend} && $opt{backend}) {
+   }
+   elsif ( exists $opt{backend} && $opt{backend} ) {
       my $be = __PACKAGE__.'::'.$opt{backend};
       eval "require $be";
-      die "Unable to locate the $class back-end $be: $@" if $@;
+      croak "Unable to locate the $class back-end $be: $@" if $@;
       $BACKEND = $opt{backend} eq 'AC' ? 'GD' : $opt{backend};
-   } else {
+   }
+   else {
       require GD::SecurityImage::GD;
       $BACKEND = 'GD';
    }
    push @ISA, 'GD::SecurityImage::' . $BACKEND;
    push @ISA, qw(GD::SecurityImage::Styles); # load styles
+   return;
 }
 
 sub new {
    my $class = shift;
-      $BACKEND || die "You didn't import $class!";
+      $BACKEND || croak "You didn't import $class!";
    my %opt   = scalar @_ % 2 ? () : (@_);
+
    my $self  = {
       IS_MAGICK       => $BACKEND eq 'Magick',
       IS_GD           => $BACKEND eq 'GD',
@@ -46,6 +51,7 @@ sub new {
       _TEXT_LOCATION_ => {}, # see info_text
    };
    bless $self, $class;
+
    my %options = (
       width      => $opt{width}               || 80,
       height     => $opt{height}              || 30,
@@ -63,9 +69,11 @@ sub new {
       thickness  => $opt{thickness}           || 0,
       _ANGLES_   => [], # angle list for scrambled images
    );
+
    if($opt{text_location} && ref $opt{text_location} && ref $opt{text_location} eq 'HASH') {
       $self->{_TEXT_LOCATION_} = { %{$opt{text_location}}, _place_ => 1 };
-   } else {
+   }
+   else {
       $self->{_TEXT_LOCATION_}{_place_} = 0;
    }
    $self->{_RNDMAX_} = $options{rndmax}; 
@@ -74,7 +82,7 @@ sub new {
    if($self->{angle}) { # validate angle
       $self->{angle} = 360 + $self->{angle} if $self->{angle} < 0;
       if($self->{angle} > 360) {
-         die "Angle parameter can take values in the range -360..360";
+         croak "Angle parameter can take values in the range -360..360";
       }
    }
 
@@ -82,13 +90,15 @@ sub new {
       if ($self->{angle}) {
          # Does the user want a fixed angle?
          push @{ $self->{_ANGLES_} }, $self->{angle};
-      } else {
+      }
+      else {
          # Generate angle range. The reason for hardcoding these is; 
          # it'll be less random for 0..60 range
          push @{ $self->{_ANGLES_} }, (0,5,8,15,22,26,29,33,35,36,40,43,45,53,56);
          push @{ $self->{_ANGLES_} }, map {360 - $_} @{ $self->{_ANGLES_} }; # push negatives
       }
    }
+
    $self->init;
    return $self;
 }
@@ -101,7 +111,7 @@ sub backends {
       my $dir = "$inc/GD/SecurityImage";
       next unless -d $dir;
       local  *DIR;
-      opendir DIR, $dir or die "opendir($dir) failed: $!";
+      opendir DIR, $dir or croak "opendir($dir) failed: $!";
       my @dir = readdir DIR;
       closedir DIR;
       push @dir_list, $dir;
@@ -115,7 +125,8 @@ sub backends {
    }
    if (defined wantarray) {
       return @list;
-   } else {
+   }
+   else {
       print "Available back-ends in $class v$VERSION are:\n\t"
             .join("\n\t", @list)
             ."\n\n"
@@ -145,7 +156,8 @@ sub random {
    my $user = shift;
    if($user and length($user) >= $self->{_RNDMAX_}) {
       $self->{_RANDOM_NUMBER_} = $user;
-   } else {
+   }
+   else {
       my @keys = @{ $self->{rnd_data} };
       my $lk   = scalar @keys;
       my $random;
@@ -159,42 +171,43 @@ sub cconvert { # convert color codes
    # GD           : return color index number
    # Image::Magick: return hex color code
    my $self   = shift;
-   my $data   = shift || die "Empty parameter passed to cconvert!";
-   unless($self->{IS_CORE}) {
-      return $self->backend_cconvert($data);
-   }
-   my $is_hex = $self->is_hex($data);
-   if($data && $self->{IS_MAGICK} && $is_hex) {
-      return $data; # data is a hex color code and Image::Magick has hex support
-   }
-   if(  $data              &&
-      ! $is_hex            &&
-      ! ref($data)         &&
-      $data !~ m{[^0-9]}   &&
-      $data >= 0
-      ) {
-      if ($self->{IS_MAGICK}) {
-         die "The number '$data' can not be transformed to a color code!";
-      } else {
-         # data is a GD color index number ...
-         # ... or it is any number! since there is no way to determine this. 
-         # GD object' s rgb() method returns 0,0,0 upon failure...
-         return $data;
+   my $data   = shift || croak "Empty parameter passed to cconvert!";
+   return $self->backend_cconvert($data) if not $self->{IS_CORE};
+
+   my $is_hex    = $self->is_hex($data);
+   my $magick_ok = $self->{IS_MAGICK} && $data && $is_hex;
+   # data is a hex color code and Image::Magick has hex support
+   return $data if $magick_ok;
+   my $color_code = $data              &&
+                    ! $is_hex          &&
+                    ! ref($data)       &&
+                    $data !~ m{[^0-9]} &&
+                    $data >= 0;
+
+   if( $color_code ) {
+      if ( $self->{IS_MAGICK} ) {
+         croak "The number '$data' can not be transformed to a color code!";
       }
-   }
-   my @rgb = $self->h2r($data);
-   if(@rgb and $self->{IS_MAGICK}) {
+      # data is a GD color index number ...
+      # ... or it is any number! since there is no way to determine this. 
+      # GD object' s rgb() method returns 0,0,0 upon failure...
       return $data;
-   } else {
-      $data = [@rgb] if @rgb;
-      # initialize if not valid
-      if(not $data || not ref $data || ref $data ne 'ARRAY' || $#{$data} != 2) {
-         $data = [0, 0, 0];
-      }
-      foreach my $i (0..$#{$data}) { # check for bad values
-         $data->[$i] = 0 if $data->[$i] > 255 or $data->[$i] < 0;
+   }
+
+   my @rgb = $self->h2r($data);
+   return $data if @rgb && $self->{IS_MAGICK};
+
+   $data = [@rgb] if @rgb;
+   # initialize if not valid
+   if(not $data || not ref $data || ref $data ne 'ARRAY' || $#{$data} != 2) {
+      $data = [0, 0, 0];
+   }
+   foreach my $i (0..$#{$data}) { # check for bad values
+      if ($data->[$i] > 255 or $data->[$i] < 0) {
+         $data->[$i] = 0;
       }
    }
+
    return $self->{IS_MAGICK} ? $self->r2h(@{$data}) # convert to hex
                              : $self->{image}->colorAllocate(@{$data});
 }
@@ -207,14 +220,14 @@ sub create {
    my $col2   = shift || [ 0, 0, 0]; # line/box color
 
    $self->{send_ctobg} = 0 if $style eq 'box'; # disable for that style
-   $self->{_COLOR_} = { # set the color hash
+   $self->{_COLOR_}    = { # set the color hash
         text  => $self->cconvert($col1),
         lines => $self->cconvert($col2),
    };
 
    # be a smart module and auto-disable ttf if we are under a prehistoric GD
-   unless ($self->{IS_MAGICK}) {
-      $method = 'normal' if defined $GD::VERSION and $GD::VERSION < 1.20;
+   if ( not $self->{IS_MAGICK} ) {
+      $method = 'normal' if $self->_versionlt(1.20);
    }
 
    if($method eq 'normal' and not $self->{gd_font}) {
@@ -222,11 +235,18 @@ sub create {
    }
 
    $style = $self->can('style_'.$style) ? 'style_'.$style : 'style_default';
-   $self->$style() unless $self->{send_ctobg};
+
+   $self->$style() if not $self->{send_ctobg};
    $self->insert_text($method);
    $self->$style() if     $self->{send_ctobg};
-   $self->rectangle(0,0,$self->{width}-1,$self->{height}-1, $self->{_COLOR_}{lines})
-      if $self->{frame}; # put a frame around the image
+
+   if ( $self->{frame} ) {
+      # put a frame around the image
+      my $w = $self->{width}  - 1;
+      my $h = $self->{height} - 1;
+      $self->rectangle( 0, 0, $w, $h, $self->{_COLOR_}{lines} );
+   }
+
    $self->{_CREATECALLED_}++;
    return $self if defined wantarray;
 }
@@ -234,28 +254,37 @@ sub create {
 sub particle {
    # Create random dots. They'll cover all over the surface
    my $self = shift;
-   die "particle() must be called 'after' create()!" unless $self->{_CREATECALLED_};
+   croak "particle() must be called 'after' create()" if not $self->{_CREATECALLED_};
    my $big  = $self->{height} > $self->{width} ? $self->{height} : $self->{width};
    my $f    = shift || $big * 20; # particle density
    my $dots = shift || 1; # number of multiple dots
    my $int  = int $big / 20;
+
    my @random;
    for (my $x = $int; $x <= $big; $x += $int) {
       push @random, $x;
    }
+
+   my $tc  = $self->{_COLOR_}{text};
+   my $len = @random;
+   my $r   = sub { $random[ int rand $len ] };
    my($x, $y, $z);
+
    for (1..$f) {
       $x = int rand $self->{width};
       $y = int rand $self->{height};
       foreach $z (1..$dots) {
-         $self->setPixel($x + $z                            , $y + $z                            , $self->{_COLOR_}{text});
-         $self->setPixel($x + $z + $random[int rand @random], $y + $z + $random[int rand @random], $self->{_COLOR_}{text});
+         $self->setPixel($x + $z         , $y + $z         , $tc);
+         $self->setPixel($x + $z + $r->(), $y + $z + $r->(), $tc);
       }
    }
+   undef @random;
+   undef $r;
+
    return $self if defined wantarray;
 }
 
-sub raw {shift->{image}} # raw image object
+sub raw { $_[0]->{image} } # raw image object
 
 sub info_text { # set text location
    # x      => 'left|right',  # text-X
@@ -267,15 +296,15 @@ sub info_text { # set text location
    # scolor => '#FFFFFF',     # strip color
    # text   => 'blah',        # modifies random code
    my $self = shift;
-   die "info_text() must be called 'after' create()!" unless $self->{_CREATECALLED_};
-   my %o = scalar(@_) % 2 ? () : (qw/x right y up strip 1/, @_);
-   return unless %o;
+   croak "info_text() must be called 'after' create()" if not $self->{_CREATECALLED_};
+   my %o = scalar(@_) % 2 ? () : ( qw/ x right y up strip 1 /, @_ );
+   return if not %o;
 
-   $o{scolor} = $self->cconvert($o{scolor}) if $o{scolor};
-   $self->{_TEXT_LOCATION_}->{_place_} = 1;
-   local $self->{_RANDOM_NUMBER_} = delete $o{text} if $o{text};
-   local $self->{_COLOR_}{text}   = $self->cconvert(delete $o{color}) if $o{color};
-   local $self->{ptsize}          = delete $o{ptsize} if $o{ptsize};
+   $self->{_TEXT_LOCATION_}{_place_} = 1;
+   $o{scolor}                        = $self->cconvert($o{scolor})       if $o{scolor};
+   local $self->{_RANDOM_NUMBER_}    = delete $o{text}                   if $o{text};
+   local $self->{_COLOR_}{text}      = $self->cconvert(delete $o{color}) if $o{color};
+   local $self->{ptsize}             = delete $o{ptsize}                 if $o{ptsize};
 
    local $self->{scramble} = 0; # disable. we need a straight text
    local $self->{angle}    = 0; # disable. RT:14618
@@ -291,14 +320,17 @@ sub add_strip { # adds a strip to the background of the text
    my $self = shift;
    my($x, $y, $box_w, $box_h) = @_;
    my $tl    = $self->{_TEXT_LOCATION_};
-   my $black = $self->cconvert($self->{_COLOR_}{text} ? $self->{_COLOR_}{text} : [0,0,0]);
-   my $white = $self->cconvert($tl->{scolor}          ? $tl->{scolor}          : [255,255,255]);
+   my $c     = $self->{_COLOR_} || {};
+   my $black = $self->cconvert( $c->{text}    ? $c->{text}    : [   0,   0,   0 ] );
+   my $white = $self->cconvert( $tl->{scolor} ? $tl->{scolor} : [ 255, 255, 255 ] );
    my $x2    = $tl->{x} eq 'left' ? $box_w : $self->{width};
    my $y2    = $self->{height} - $box_h;
-   my $i     = $self->{IS_MAGICK} ? $self : $self->{image};
+   my $i     = $self->{IS_MAGICK} ? $self  : $self->{image};
    my $up    = $tl->{y} eq 'up';
-   $i->filledRectangle($up ? ($x-1, 0, $x2, $y+1) : ($x-1, $y2-1, $x2  , $self->{height}  ), $black);
-   $i->filledRectangle($up ? ($x  , 1, $x2-2, $y) : ($x  , $y2  , $x2-2, $self->{height}-2), $white);
+   my $h     = $self->{height};
+   $i->filledRectangle($up ? ($x-1, 0, $x2, $y+1) : ($x-1, $y2-1, $x2  , $h  ), $black);
+   $i->filledRectangle($up ? ($x  , 1, $x2-2, $y) : ($x  , $y2  , $x2-2, $h-2), $white);
+   return;
 }
 
 sub r2h {
@@ -326,12 +358,12 @@ sub is_hex {
 }
 
 sub AUTOLOAD {
-   my $self = shift;
+   my $self  = shift;
+   my $class = ref $self;
    (my $name = $AUTOLOAD) =~ s,.*:,,;
-   if ($name eq 'gdbox_empty') { # fake method for GD compatibility. only GD has this
-      return 0;
-   }
-   die "Unknown ".ref($self)." method '$name'!";
+   # fake method for GD compatibility. only GD has this
+   return 0 if $name eq 'gdbox_empty';
+   croak "Unknown $class method '$name'";
 }
 
 sub DESTROY {}
@@ -412,7 +444,10 @@ for migration from C<Authen::Captcha> to C<GD::SecurityImage>.
 
 This module is B<just an image generator>. Not a I<captcha handler>.
 The validation of the generated graphic is left to your programming 
-taste.
+taste. But there are some I<captcha handlers> for several Perl FrameWorks.
+If you are an user of one of these frameworks, see  
+L</"GD::SecurityImage Implementations"> in L</"SEE ALSO"> section
+for information.
 
 =head1 COLOR PARAMETERS
 
@@ -817,6 +852,8 @@ this mandatory methods.
    ellipse		draws an ellipse
    arc			draws an arc
    setThickness		sets the thickness of the lines when drawing something
+   _versiongt           backend version is greater or equal to supplied param?
+   _versionlt           backend version is smaller than supplied param?
 
 and
 
@@ -825,7 +862,7 @@ and
 See GD::SecurityImage::Magick for the first part of methods and see 
 cconvert() method in GD::SecurityImage to define such a method. Your 
 backend_cconvert() method must be capable of handling both HEX and RGB 
-values. The parametes passed to drawing methods (like line()) are 
+values. The parameters passed to drawing methods (like line()) are 
 in GD format. See the L<GD> module for examples.
 
 You can then name your distro as 'GD::SecurityImage::X' and anyone can use 
@@ -844,6 +881,165 @@ C<GD::SecurityImage>.
 Download the distribution from a CPAN mirror near you, if you 
 don't have the files.
 
+=begin html
+
+<!-- this h1 part is for search.cpan.org -->
+<h1>
+<a class = 'u' 
+   href  = '#___top'
+   title ='click to go to top of document'
+   name  = "IMAGE SAMPLES"
+>IMAGE SAMPLES</a>
+</h1>
+
+<p>
+All TTF samples generated with the bundled font <i>StayPuft.ttf</i>,
+unless stated otherwise. Most of the samples here can be generated with 
+running the test suite that comes with the GD::SecurityImage distribution. 
+However, images that are generated with random angles will indeed be a 
+little different after you run the test suite on your system.
+</p>
+
+<p>
+All random codes have a length of six (6) characters, unless stated otherwise.
+So, (for example) there is no clipping in <code>ELLIPS</code>.
+</p>
+
+<table border      = "1"
+       cellpadding = "4"
+       cellspacing = "1"
+>
+   <tr>
+      <td colspan="2" style="text-align:center;font-weight:bold">
+         <br />
+         Images generated with GD
+         <br />
+         <br />
+      </td>
+   </tr>
+
+   <tr><td colspan="2">&#160;</td></tr>
+
+   <tr>
+      <td> Standard interface. Font: <b>gdGiantFont</b> </td>
+      <td> Style: <b>rect</b>                           </td>
+   </tr>
+   <tr>
+      <td><img border="0" src="http://img505.imageshack.us/img505/1365/gdnormal03boxvi9.png" /></td>
+      <td><img border="0" src="http://img524.imageshack.us/img524/9065/gdttf02rectiz2.png"   /></td>
+   </tr>
+
+   <tr><td colspan="2">&#160;</td></tr>
+
+   <tr>
+      <td>Style: <b>rect</b>. Scrambled with random angles.</td>
+      <td>Style: <b>circle</b>. Scrambled with a fixed angle.</td>
+   </tr>
+   <tr>
+      <td><img border="0" src="http://img505.imageshack.us/img505/8893/gdttfscramble02rectma0.png" /></td>
+      <td><img border="0" src="http://img512.imageshack.us/img512/8207/gdttfscramblefixed04cirwt1.png" /></td>
+   </tr>
+
+   <tr><td colspan="2">&#160;</td></tr>
+
+   <tr>
+      <td>Style: <b>default</b>. Scrambled with a fixed angle. <br />Info text at the top right.</td>
+      <td>Style: <b>circle</b>. Scrambled with random angles. <br />Font is: <i>Transformers.ttf</i></td>
+   </tr>
+   <tr>
+      <td><img border="0" src="http://img524.imageshack.us/img524/1452/gdttfscramblefixedinfotuz9.png"  /></td>
+      <td><img border="0" src="http://img505.imageshack.us/img505/739/differentdz6.png" /></td>
+   </tr>
+
+</table>
+
+<p>&nbsp;</p>
+
+<table border      = "1"
+       cellpadding = "4"
+       cellspacing = "2"
+>
+   <tr>
+      <td colspan="2" style="text-align:center;font-weight:bold">
+         <br />
+         Images generated with Image::Magick
+         <br />
+         <br />
+      </td>
+   </tr>
+
+   <tr><td colspan="2">&#160;</td></tr>
+
+   <tr>
+      <td>Style: <b>circle</b>.</td>
+      <td>Style: <b>box</b>. Scrambled with random angles.</td>
+   </tr>
+   <tr>
+      <td><img border="0" src="http://img524.imageshack.us/img524/1233/magick04circleru3.png"       /></td>
+      <td><img border="0" src="http://img521.imageshack.us/img521/7235/magickscramble03boxmb2.png" /></td>
+   </tr>
+
+
+   <tr><td colspan="2">&#160;</td></tr>
+   <tr>
+      <td>Style: <b>circle</b>. Scrambled with a fixed angle.</td>
+      <td>Style: <b>ellipse</b>. Scrambled with a fixed angle.<br /> Info text at the top right.</td>
+   </tr>
+
+   <tr>
+      <td><img border="0" src="http://img139.imageshack.us/img139/7227/magickscramblefixed04cihd4.png" /></td>
+      <td><img border="0" src="http://img139.imageshack.us/img139/9484/magickscramblefixedinfooj6.png" /></td>
+   </tr>
+
+   <tr><td colspan="2">&#160;</td></tr>
+
+   <tr>
+      <td>Style: <b>ec</b>. Scrambled with random angles.<br /> Info text at the top right.</td>
+      <td>Style: <b>ec</b>. Scrambled with random angles<b><sup>1</sup>.</b></td>
+   </tr>
+   <tr>
+      <td><img border="0" src="http://img139.imageshack.us/img139/9587/magickscrambleinfotext0bz8.png" /></td>
+      <td><img border="0" src="http://img505.imageshack.us/img505/347/burakrw7.gif" /></td>
+   </tr>
+
+</table>
+
+
+<p>
+<sup><b>1</b></sup>: This image is generated with this code:</p>
+<p>
+<pre>
+<span style="color: #8B008B; font-weight:bold;">use</span> <span style="color: #000000;">GD::SecurityImage</span> <span style="color: #000000;">backend</span> <span style="color: #000000;">=&gt;</span> <span style="color: #CD5555;">'Magick'</span><span style="color: #000000;">;</span>
+<span style="color: #8B008B; font-weight:bold;">my</span><span style="color: #000000;">(</span><span style="color: #00688B;">$data</span><span style="color: #000000;">,</span> <span style="color: #00688B;">$mime</span><span style="color: #000000;">,</span> <span style="color: #00688B;">$rnd</span><span style="color: #000000;">)</span> = <span style="color: #000000;">GD::SecurityImage</span>
+<span style="color: #000000;">-&gt;new</span><span style="color: #000000;">(</span>
+   <span style="color: #000000;">width</span>      <span style="color: #000000;">=&gt;</span> <span style="color: #B452CD;">420</span><span style="color: #000000;">,</span>
+   <span style="color: #000000;">height</span>     <span style="color: #000000;">=&gt;</span> <span style="color: #B452CD;">100</span><span style="color: #000000;">,</span>
+   <span style="color: #000000;">ptsize</span>     <span style="color: #000000;">=&gt;</span> <span style="color: #B452CD;">40</span><span style="color: #000000;">,</span>
+   <span style="color: #000000;">lines</span>      <span style="color: #000000;">=&gt;</span> <span style="color: #B452CD;">20</span><span style="color: #000000;">,</span>
+   <span style="color: #000000;">thickness</span>  <span style="color: #000000;">=&gt;</span> <span style="color: #B452CD;">4</span><span style="color: #000000;">,</span>
+   <span style="color: #000000;">rndmax</span>     <span style="color: #000000;">=&gt;</span> <span style="color: #B452CD;">5</span><span style="color: #000000;">,</span>
+   <span style="color: #000000;">scramble</span>   <span style="color: #000000;">=&gt;</span> <span style="color: #B452CD;">1</span><span style="color: #000000;">,</span>
+   <span style="color: #000000;">send_ctobg</span> <span style="color: #000000;">=&gt;</span> <span style="color: #B452CD;">1</span><span style="color: #000000;">,</span>
+   <span style="color: #000000;">bgcolor</span>    <span style="color: #000000;">=&gt;</span> <span style="color: #CD5555;">'#009999'</span><span style="color: #000000;">,</span>
+   <span style="color: #000000;">font</span>       <span style="color: #000000;">=&gt;</span> <span style="color: #CD5555;">'StayPuft.ttf'</span><span style="color: #000000;">,</span>
+<span style="color: #000000;">)</span>
+<span style="color: #00688B;">-&gt;random</span><span style="color: #000000;">(</span><span style="color: #CD5555;">'BURAK'</span><span style="color: #000000;">)</span>
+<span style="color: #00688B;">-&gt;create</span><span style="color: #000000;">(</span> <span style="color: #CD5555;">qw/ ttf ec #0066CC #0066CC /</span> <span style="color: #000000;">)</span>
+<span style="color: #00688B;">-&gt;particle</span><span style="color: #000000;">(</span><span style="color: #B452CD;">300</span><span style="color: #000000;">,</span> <span style="color: #B452CD;">500</span><span style="color: #000000;">)</span>
+<span style="color: #00688B;">-&gt;out</span><span style="color: #000000;">;</span>
+
+</pre>
+</p>
+
+<p>
+All images in this document are generously hosted by 
+<a href="http://imageshack.us">ImageShack</a>
+<a href="http://imageshack.us"><img src="http://imageshack.us/img/imageshack.png" border="0" /></a>
+
+</p>
+
+=end html
+
 =head1 ERROR HANDLING
 
 C<die> is called in some methods if something fails. You may need to 
@@ -869,7 +1065,8 @@ may prevent this.
 
 =head1 BUGS
 
-Contact the author if you find any bugs. You can also send requests.
+See the L</SUPPORT> section if you have a bug or 
+request to report.
 
 =head2 Image::Magick bug
 
@@ -1013,15 +1210,17 @@ be drawn.
 
 =head1 SEE ALSO
 
+=head2 Other CAPTCHA Implementations & Perl Modules
+
 =over 4
 
 =item *
 
-L<GD>, L<Image::Magick>, L<ImagePwd>, L<Authen::Captcha>.
+L<GD>, L<Image::Magick>
 
 =item *
 
-L<GD::SecurityImage::AC>: C<Authen::Captcha> drop-in replacement module.
+L<ImagePwd>, L<Authen::Captcha>.
 
 =item *
 
@@ -1036,20 +1235,78 @@ The CAPTCHA project: L<http://www.captcha.net/>.
 A definition of CAPTCHA (From Wikipedia, the free encyclopedia):
 L<http://en.wikipedia.org/wiki/Captcha>.
 
+=item *
+
+L<WebService::CaptchasDotNet>: A Perl interface to
+I<http://captchas.net> free captcha service. I<captchas.net>
+also offers I<audio> captchas.
+
 =back
 
+=head2 GD::SecurityImage Implementations
+
+=over 4
+
+=item *
+
+L<GD::SecurityImage::AC>: C<Authen::Captcha> drop-in replacement module.
+
+=item *
+
+L<Sledge::Plugin::Captcha>
+
+=item *
+
+L<Catalyst::Plugin::Captcha>
+
+=item *
+
+L<CGI::Application::Plugin::CAPTCHA >
+
+=item *
+
+L<Angerwhale::Controller::Captcha>
+
+=back
+
+=head2 Software Using GD::SecurityImage
+
+If your software uses C<GD::SecurityImage> for captcha generation and
+want to appear in this document, contact the author.
+
+=head1 SUPPORT
+
+=head2 BUG REPORTS
+
+All bug reports and wishlist items B<must> be reported via
+the CPAN RT system. It is accessible at
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=GD-SecurityImage>.
+
+=head2 DISCUSSION FORUM
+
+C<CPAN::Forum> is a place for discussing C<CPAN>
+modules. It also has a C<GD::SecurityImage> section at
+L<http://www.cpanforum.com/dist/GD-SecurityImage>.
+
+=head2 RATINGS
+
+If you like or hate or have some suggestions about
+C<GD::SecurityImage>, you can comment/rate the distribution via 
+the C<CPAN Ratings> system: 
+L<http://cpanratings.perl.org/dist/GD-SecurityImage>.
+
 =head1 AUTHOR
 
-Burak Grsoy, E<lt>burakE<64>cpan.orgE<gt>
+Burak GE<252>rsoy, E<lt>burakE<64>cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2004-2006 Burak Grsoy. All rights reserved.
+Copyright 2004-2007 Burak GE<252>rsoy. All rights reserved.
 
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.8.7 or, 
+it under the same terms as Perl itself, either Perl version 5.8.8 or, 
 at your option, any later version of Perl 5 you may have available.
 
 =cut
